@@ -51,18 +51,9 @@
 static void usage(void);
 static void help(void);
 
-const char *gozillarc = ".gozillarc";
-#ifdef __DJGPP__
-const char *dos_gozillarc = "_gozillarc";
-#endif
-STRHASH *sh;
-
-static void load_alias(void);
-static const char *alias(const char *);
 int main(int, char **);
 void getdefinitionURL(const char *, const char *, STRBUF *);
 void getURL(const char *, const char *, STRBUF *);
-int isprotocol(const char *);
 int convertpath(const char *, const char *, const char *, STRBUF *);
 void makefileurl(const char *, int, STRBUF *);
 void show_page_by_url(const char *, const char *);
@@ -72,10 +63,8 @@ void show_page_by_url(const char *, const char *);
 
 const char *cwd, *root, *dbpath;
 
-int bflag;
 int pflag;
 int qflag;
-int Cflag;
 int vflag;
 int show_version;
 int linenumber = 0;
@@ -96,78 +85,6 @@ help(void)
 	exit(0);
 }
 
-/**
- * load_alias: load alias value.
- *
- * [$HOME/.gozillarc]
- * +-----------------------
- * |a:http://www.gnu.org
- * |f = file:/usr/share/xxx.html
- * |www	http://www.xxx.yyy/
- */
-static void
-load_alias(void)
-{
-	FILE *ip;
-	STRBUF *sb = strbuf_open(0);
-	char *p;
-	int flag = STRBUF_NOCRLF;
-	struct sh_entry *ent;
-
-	sh = strhash_open(10);
-	if (!(p = get_home_directory()))
-		goto end;
-	if (!test("r", makepath(p, gozillarc, NULL)))
-#ifdef __DJGPP__
-		if (!test("r", makepath(p, dos_gozillarc, NULL)))
-#endif
-			goto end;
-	if (!(ip = fopen(makepath(p, gozillarc, NULL), "r")))
-#ifdef __DJGPP__
-		if (!(ip = fopen(makepath(p, dos_gozillarc, NULL), "r")))
-#endif
-			goto end;
-	while ((p = strbuf_fgets(sb, ip, flag)) != NULL) {
-		char *name, *value;
-
-		flag &= ~STRBUF_APPEND;
-		if (*p == '#')
-			continue;
-		if (strbuf_unputc(sb, '\\')) {
-			flag |= STRBUF_APPEND;
-			continue;
-		}
-		while (*p && isblank(*p))				/* skip spaces */
-			p++;
-		name = p;
-		while (*p && !isblank(*p) && *p != '=' && *p != ':')	/* get name */
-			p++;
-		*p++ = 0;
-		while (*p && (isblank(*p) || *p == '=' || *p == ':'))
-			p++;
-		value = p;						/* get value */
-		ent = strhash_assign(sh, name, 1);
-		if (ent->value)
-			(void)free(ent->value);
-		ent->value = check_strdup(value);
-	}
-	fclose(ip);
-end:
-	strbuf_close(sb);
-}
-/**
- * alias: get alias value.
- *
- *	@param[in]	alias_name	alias name
- *	@return			its value
- */
-static const char *
-alias(const char *alias_name)
-{
-	struct sh_entry *ent = strhash_assign(sh, alias_name, 0);
-	return ent ? ent->value : NULL;
-}
-
 /**
  * locate_HTMLdir: locate HTML directory made by htags(1).
  *
@@ -196,7 +113,6 @@ main(int argc, char **argv)
 {
 	char c;
 	const char *p, *browser = NULL, *definition = NULL;
-	STRBUF *arg = strbuf_open(0);
 	STRBUF *URL = strbuf_open(0);
 
 	while (--argc > 0 && ((c = (++argv)[0][0]) == '-' || c == '+')) {
@@ -211,6 +127,8 @@ main(int argc, char **argv)
 			} else if (!strcmp("--verbose", argv[0])) {
 				vflag++;
 				qflag = 0;
+			} else if (!strcmp("--debug", argv[0])) {
+				debug = 1;
 			} else
 				usage();
 			continue;
@@ -246,10 +164,12 @@ main(int argc, char **argv)
 	}
 	if (show_version)
 		version(progname, vflag);
-	/*
-	 * Load aliases from .gozillarc.
-	 */
-	load_alias();
+	if (!definition) {
+		if (argc <= 0)
+			usage();
+		if (!test("f", argv[0]))
+			die("file '%s' not found.", argv[0]);
+	}
 	/*
 	 * Open configuration file.
 	 */
@@ -259,8 +179,6 @@ main(int argc, char **argv)
 	 */
 	if (!browser && getenv("BROWSER"))
 		browser = getenv("BROWSER");
-	if (!browser && alias("BROWSER"))
-		browser = alias("BROWSER");
 	/*
 	 * In DOS & Windows, let the file: association handle it.
 	 */
@@ -268,68 +186,27 @@ main(int argc, char **argv)
 	if (!browser)
 		browser = "firefox";
 #endif
-
-	/*
-	 * Replace alias name.
-	 */
-	if (definition == NULL) {
-		if (argc <= 0)
-			usage();
-		strbuf_puts(arg, argv[0]);
-		/*
-		 * Replace with alias value.
-		 */
-		if ((p = alias(strbuf_value(arg))) != NULL) {
-			strbuf_reset(arg);
-			strbuf_puts(arg, p);
-		}
-	}
 	/*
 	 * Get URL.
 	 */
 	{
-		char *argument = strbuf_value(arg);
+		const char *HTMLdir = NULL;
 
+		if (setupdbpath(0) == 0) {
+			cwd = get_cwd();
+			root = get_root();
+			dbpath = get_dbpath();
+			HTMLdir = locate_HTMLdir();
+		} 
 		/*
-		 * Protocol (xxx://...)
+		 * Make a URL of hypertext from the argument.
 		 */
-		if (!definition && isprotocol(argument)) {
-			strbuf_puts(URL, argument);
-		} else {
-			const char *HTMLdir = NULL;
-
-			if (setupdbpath(0) == 0) {
-				cwd = get_cwd();
-				root = get_root();
-				dbpath = get_dbpath();
-				HTMLdir = locate_HTMLdir();
-			} 
-			/*
-			 * Make a URL of hypertext from the argument.
-			 */
-			if (HTMLdir != NULL) {
-				if (definition)
-					getdefinitionURL(definition, HTMLdir, URL);
-				else
-					getURL(argument, HTMLdir, URL);
-			}
-			/*
-			 * Make a file URL.
-			 */
-			else if (test("fr", argument) || test("dr", argument)) {
-				char cwd[MAXPATHLEN];
-				char result[MAXPATHLEN];
-
-				if (vgetcwd(cwd, sizeof(cwd)) == NULL)
-					die("cannot get current directory.");
-				if (rel2abs(argument, cwd, result, sizeof(result)) == NULL)
-					die("rel2abs failed.");
-				strbuf_puts(URL, "file://");
-				strbuf_puts(URL, result);
-			} else {
-				die_with_code(1, "file '%s' not found.", argument);
-			}
-		}
+		if (HTMLdir == NULL)
+			die("HTML directory not found.");
+		if (definition)
+			getdefinitionURL(definition, HTMLdir, URL);
+		else
+			getURL(argv[0], HTMLdir, URL);
 	}
 	if (pflag) {
 		fprintf(stdout, "%s\n", strbuf_value(URL));
@@ -401,9 +278,6 @@ getURL(const char *file, const char *htmldir, STRBUF *URL)
 	char *p;
 	char buf[MAXPATHLEN];
 	STRBUF *sb = strbuf_open(0);
-
-	if (!test("f", file) && !test("d", file))
-		die("file '%s' not found.", file);
 	p = normalize(file, get_root_with_slash(), cwd, buf, sizeof(buf));
 	if (p != NULL && convertpath(dbpath, htmldir, p, sb) == 0)
 		makefileurl(strbuf_value(sb), linenumber, URL);
@@ -411,31 +285,6 @@ getURL(const char *file, const char *htmldir, STRBUF *URL)
 		makefileurl(realpath(file, buf), 0, URL);
 	strbuf_close(sb);
 }
-/**
- * isprotocol: return 1 if url has a procotol.
- *
- *	@param[in]	url	URL
- *	@return		1: protocol, 0: file
- */
-int
-isprotocol(const char *url)
-{
-	const char *p;
-
-	if (locatestring(url, "file:", MATCH_AT_FIRST))
-		return 1;
-	/*
-	 * protocol's style is like http://xxx.
-	 */
-	for (p = url; *p && *p != ':'; p++)
-		if (!isalnum(*p))
-			return 0;
-	if (!*p)
-		return 0;
-	if (*p++ == ':' && *p++ == '/' && *p == '/')
-		return 1;
-	return 0;
-}
 /**
  * convertpath: convert source file into hypertext path.
  *
@@ -609,11 +458,18 @@ make_url_file(const char *url)
 	return urlfile;
 }
 void
+dump_argv(char *argv[]) {
+	int i;
+	for (i = 0; argv[i] != NULL; i++) {
+		fprintf(stderr, "argv[%d] = |%s|\n", i, argv[i]);
+	}
+}
+void
 show_page_by_url(const char *browser, const char *url)
 {
+	char *argv[4];
 	STRBUF  *sb = strbuf_open(0);
 	STRBUF  *arg = strbuf_open(0);
-
 	/*
 	 * Browsers which have openURL() command.
 	 */
@@ -625,31 +481,42 @@ show_page_by_url(const char *browser, const char *url)
 	    locatestring(browser, "netscape", MATCH_AT_LAST) ||
 	    locatestring(browser, "netscape-remote", MATCH_AT_LAST))
 	{
-		strbuf_puts(sb, quote_shell(browser));
-		strbuf_putc(sb, ' ');
-		strbuf_puts(sb, "-remote");
-		strbuf_putc(sb, ' ');
+		if (debug)
+			fprintf(stderr, "Netscape\n");
+		argv[0] = (char *)browser;
+		argv[1] = "-remote";
 		strbuf_sprintf(arg, "openURL(%s)", url);
-		strbuf_puts(sb, quote_shell(strbuf_value(arg)));
-		system(strbuf_value(sb));
+		argv[2] = strbuf_value(arg);
+		argv[3] = NULL;
+		if (debug)
+			dump_argv(argv);
+		execvp(browser, argv);
 	}
 	/*
 	 * Load default browser of OSX.
 	 */
 	else if (!strcmp(browser, "osx-default")) {
-		strbuf_puts(sb, "open");
-		strbuf_putc(sb, ' ');
-		strbuf_puts(sb, quote_shell(make_url_file(url)));
-		system(strbuf_value(sb));
+		if (debug)
+			fprintf(stderr, "OSX default\n");
+		argv[0] = "open";
+		argv[1] = make_url_file(url);
+		argv[2] = NULL;
+		if (debug)
+			dump_argv(argv);
+		execvp("open", argv);
 	}
 	/*
 	 * Generic browser.
 	 */
 	else {
-		strbuf_puts(sb, quote_shell(browser));
-		strbuf_putc(sb, ' ');
-		strbuf_puts(sb, quote_shell(url));
-		system(strbuf_value(sb));
+		if (debug)
+			fprintf(stderr, "Generic browser\n");
+		argv[0] = (char *)browser;
+		argv[1] = (char *)url;
+		argv[2] = NULL;
+		if (debug)
+			dump_argv(argv);
+		execvp(browser, argv);
 	}
 	strbuf_close(sb);
 	strbuf_close(arg);
