@@ -13,11 +13,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
+ * 3. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
@@ -48,15 +44,14 @@ static char sccsid[] = "@(#)bt_conv.c	8.5 (Berkeley) 8/17/94";
 
 static void mswap(PAGE *);
 
-/*
- * __BT_BPGIN, __BT_BPGOUT --
+/**
+ * __BT_BPGIN --
  *	Convert host-specific number layout to/from the host-independent
  *	format stored on disk.
  *
- * Parameters:
- *	t:	tree
- *	pg:	page number
- *	h:	page to convert
+ *	@param t	tree
+ *	@param pg	page number
+ *	@param pp	page to convert
  */
 void
 __bt_pgin(t, pg, pp)
@@ -126,6 +121,15 @@ __bt_pgin(t, pg, pp)
 		}
 }
 
+/**
+ * __BT_BPGOUT --
+ *	Convert host-specific number layout to/from the host-independent
+ *	format stored on disk.
+ *
+ *	@param t	tree
+ *	@param pg	page number
+ *	@param pp	page to convert
+ */
 void
 __bt_pgout(t, pg, pp)
 	void *t;
@@ -194,11 +198,10 @@ __bt_pgout(t, pg, pp)
 	M_16_SWAP(h->upper);
 }
 
-/*
+/**
  * MSWAP -- Actually swap the bytes on the meta page.
  *
- * Parameters:
- *	p:	page to convert
+ *	@param pg	page to convert
  */
 static void
 mswap(pg)
